import type { UseSignUpReturn } from '@clerk/types';
import type { ToComputedRefs } from '../utils';
type UseSignUp = () => ToComputedRefs<UseSignUpReturn>;
/**
 * Returns the current [`SignUp`](https://clerk.com/docs/references/javascript/sign-up) object which provides
 * methods and state for managing the sign-up flow.
 *
 * @example
 * <script setup>
 * import { useSignUp } from '@clerk/vue'
 *
 * const { isLoaded, signUp } = useSignUp()
 * </script>
 *
 * <template>
 *   <div v-if="!isLoaded">
 *     <!-- Handle loading state -->
 *   </div>
 *
 *   <div v-else>
 *     The current sign-up attempt status is {{ signUp.status }}.
 *   </div>
 * </template>
 */
export declare const useSignUp: UseSignUp;
export {};
